#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SELADD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SELADD_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/seladd.hpp>

#endif
